@@ -11,19 +11,19 @@ use crate::{
     TypeConstructor,
 };
 
-pub struct ClosureConstructor<TType: 'static>  {
+pub struct ClosureConstructor<TType: Sync + Send + 'static>  {
     async_ctor: AsyncCallback<DependencyContext, BuildDependencyResult<TType>>,
 }
 
-impl<TType: 'static> ClosureConstructor<TType> {
+impl<TType: Sync + Send + 'static> ClosureConstructor<TType> {
     pub fn new(closure: AsyncCallback<DependencyContext, BuildDependencyResult<TType>>) -> Self {
         Self { async_ctor: closure }
     }
 }
 
-#[async_trait(?Send)]
-impl<T> TypeConstructor for ClosureConstructor<T> {
-    async fn ctor(&self, ctx: DependencyContext) -> BuildDependencyResult<Box<dyn Any>> {
-        Ok(Box::new((self.async_ctor)(ctx).await?) as Box<dyn Any>) 
+#[async_trait]
+impl<T: Sync + Send + 'static> TypeConstructor for ClosureConstructor<T> {
+    async fn ctor(&self, ctx: DependencyContext) -> BuildDependencyResult<Box<dyn Any + Sync + Send>> {
+        Ok(Box::new((self.async_ctor)(ctx).await?) as Box<dyn Any + Sync + Send>) 
     }
 }
\ No newline at end of file
