@@ -21,7 +21,7 @@ impl Constructor for TransientDependency1 {
         ctx.set_transient::<TransientDependency3>().await.map_err(|e| BuildDependencyError::AddDependencyError { err: e })?;
 
         Ok(Self {
-            d1: ctx.get_transient().await?,
+            d1: ctx.get().await?,
         })
     }
 }
@@ -35,7 +35,7 @@ struct TransientDependency2 {
 impl Constructor for TransientDependency2 {
     async fn ctor(ctx: crate::DependencyContext) ->  BuildDependencyResult<Self> {
         Ok(Self {
-            d2: ctx.get_transient().await?,
+            d2: ctx.get().await?,
         })
     }
 }
@@ -61,7 +61,7 @@ async fn single_transient() {
     root_context.set_transient::<TransientDependency1>().await.unwrap();
     root_context.set_transient::<TransientDependency2>().await.unwrap();
 
-    let dependency = root_context.get_transient::<TransientDependency1>().await.unwrap();
+    let dependency = root_context.get::<TransientDependency1>().await.unwrap();
 
     assert_eq!(dependency.d1.d2.str, "test".to_string());
 }
\ No newline at end of file
