@@ -14,7 +14,7 @@ struct TransientDependency1 {
 impl Constructor for TransientDependency1 {
     async fn ctor(ctx: crate::DependencyContext) -> BuildDependencyResult<Self> {
         Ok(Self {
-            d2: ctx.get_transient().await?,
+            d2: ctx.get().await?,
         })
     }
 }
@@ -28,7 +28,7 @@ struct TransientDependency2 {
 impl Constructor for TransientDependency2 {
     async fn ctor(ctx: crate::DependencyContext) ->  BuildDependencyResult<Self> {
         Ok(Self {
-            d1: Box::new(ctx.get_transient().await?),
+            d1: Box::new(ctx.get().await?),
         })
     }
 }
@@ -46,7 +46,7 @@ async fn nested_dependency_cycle_reference() {
     root_context.set_transient::<TransientDependency1>().await.unwrap();
     root_context.set_transient::<TransientDependency2>().await.unwrap();
 
-    let dependency = root_context.get_transient::<TransientDependency1>().await;
+    let dependency = root_context.get::<TransientDependency1>().await;
 
     assert_eq!(dependency.err(), Some(BuildDependencyError::CyclicReference {
         id: TypeId::of::<TransientDependency1>(),
