@@ -18,11 +18,12 @@ impl Constructor for ScopedDependency {
 async fn remove_scoped_dependency() {
     use crate::DependencyContext;
     use crate::extensions::ConstructedDependencySetStrategy;
+    use std::sync::Weak;
 
     let mut root_context = DependencyContext::new_root();
     root_context.set_scoped::<ScopedDependency>().await.unwrap();
 
-    let dependency = root_context.get_scoped::<ScopedDependency>().await.unwrap();
+    let dependency = root_context.get::<Weak<ScopedDependency>>().await.unwrap();
 
     assert!(dependency.upgrade().is_some());
 
@@ -30,7 +31,7 @@ async fn remove_scoped_dependency() {
 
     assert!(dependency.upgrade().is_none()); // зависимость удалилась, т.к. не осталось ссылок на скоуп
 
-    let dependency = root_context.get_scoped::<ScopedDependency>().await.unwrap();
+    let dependency = root_context.get::<Weak<ScopedDependency>>().await.unwrap();
 
     root_context.set_empty_scope(); // устанавливаем новый чистый scope, ссылка на старый скоуп ранее сохранена в new_scope
 
