@@ -1,4 +1,5 @@
 use async_trait::async_trait;
+use tokio::sync::RwLock;
 
 use crate::{Constructor, types::BuildDependencyResult};
 
@@ -18,23 +19,23 @@ impl Constructor for ScopedDependency {
 async fn single_scoped() {
     use crate::DependencyContext;
     use crate::extensions::ConstructedDependencySetStrategy;
-    use std::sync::Arc;
+    use std::sync::{Arc, Weak};
 
     let mut root_context = DependencyContext::new_root();
-    root_context.set_scoped::<ScopedDependency>().await.unwrap();
+    root_context.set_scoped::<RwLock<ScopedDependency>>().await.unwrap();
 
-    let dependency = root_context.get_scoped::<ScopedDependency>().await.unwrap();
+    let dependency = root_context.get::<Weak<RwLock<ScopedDependency>>>().await.unwrap();
 
     assert_eq!(dependency.upgrade().unwrap().read().await.str, "test".to_string());
 
-    let dependency2 = root_context.get_scoped::<ScopedDependency>().await.unwrap();
+    let dependency2 = root_context.get::<Weak<RwLock<ScopedDependency>>>().await.unwrap();
 
     assert!(Arc::ptr_eq(&dependency.upgrade().unwrap(), &dependency2.upgrade().unwrap())); // ссылки на scoped объекты созданные в одном scope совпадают
 
     let _old_scope = root_context.get_scope(); // сохраняем scope, т.к. при удалении ссылок на scope все scoped зависимости удаленного scope удаяются
     let _new_scope = root_context.set_empty_scope(); // устанавливаем новый чистый scope
 
-    let dependency3 = root_context.get_scoped::<ScopedDependency>().await.unwrap();
+    let dependency3 = root_context.get::<Weak<RwLock<ScopedDependency>>>().await.unwrap();
 
     assert!(!Arc::ptr_eq(&dependency.upgrade().unwrap(), &dependency3.upgrade().unwrap())); // dependency и dependency3 ссылаются на разные объекты т.к. созданы в разных scope
 }
\ No newline at end of file
