@@ -1,4 +1,5 @@
 use async_trait::async_trait;
+use tokio::sync::RwLock;
 
 use crate::{
     Constructor,
@@ -21,17 +22,18 @@ impl Constructor for ScopedDependency {
 async fn single_scoped_closure() {
     use crate::DependencyContext;
     use crate::extensions::ClosureDependencySetStrategy;
+    use std::sync::Weak;
 
     let root_context = DependencyContext::new_root();
-    root_context.set_scoped_closure::<ScopedDependency>(
+    root_context.set_scoped_closure::<RwLock<ScopedDependency>>(
         Box::new(move |_: crate::DependencyContext| {
             Box::pin (async move {
-                return Ok(ScopedDependency { str: "test".to_string() });
+                return Ok(RwLock::new(ScopedDependency { str: "test".to_string() }));
             })
         })
     ).await.unwrap();
 
-    let dependency = root_context.get_scoped::<ScopedDependency>().await.unwrap();
+    let dependency = root_context.get::<Weak<RwLock<ScopedDependency>>>().await.unwrap();
 
     assert_eq!(dependency.upgrade().unwrap().read().await.str, "test".to_string());
 }
\ No newline at end of file
