@@ -35,7 +35,7 @@ async fn single_transient_interface() {
     let root_context = DependencyContext::new_root();
     root_context.set_transient_interface::<dyn GetStr, TransientDependency>().await.unwrap();
 
-    let dependency = root_context.get_transient::<Box<dyn GetStr>>().await.unwrap();
+    let dependency = root_context.get::<Box<dyn GetStr>>().await.unwrap();
 
     assert_eq!(dependency.get(), "test".to_string());
 }
\ No newline at end of file
